<?php

/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package ThemaPuro
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>

<head>
	<meta charset="<?php bloginfo('charset'); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
		<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e('Skip to content', 'themapuro'); ?></a>
		<div class="container">
			<div class="row">
				<?php $show_hide_setting = get_theme_mod('icona_show_hide', 'show');
				if ($show_hide_setting == 'show') : ?>
					<div class="smallnav col-6">
						<p class="textar text-start"> <i class="<?php echo esc_html(get_theme_mod('select_icon_primo')); ?>"></i> <?php echo esc_html(get_theme_mod('phone_number')); ?> <i class="<?php echo esc_html(get_theme_mod('select_icon_secondo')); ?>"></i> <?php echo esc_html(get_theme_mod('email')); ?></p>
					</div>
					<div class="smallnav col-6">
						<p class="emaill text-end">
	
							<?php
							$facebook_url = get_theme_mod('facebook_url');
							if ($facebook_url) {
								echo '<a href="' . esc_url($facebook_url) . '" target="_blank"><i class="bi bi-facebook"></i></a>';
							}
							$instagram_url = get_theme_mod('instagram_url');
							if ($instagram_url) {
								echo '<a href="' . esc_url($instagram_url) . '" target="_blank"><i class="bi bi-instagram"></i></a>';
							}
							$whatsapp_url = get_theme_mod('whatsapp_url');
							if ($whatsapp_url) {
								echo '<a href="' . esc_url($whatsapp_url) . '" target="_blank"><i class="bi bi-whatsapp"></i></a>';
							}
							$youtube_url = get_theme_mod('youtube_url');
							if ($youtube_url) {
								echo '<a href="' . esc_url($youtube_url) . '" target="_blank"><i class="bi bi-youtube"></i></a>';
							}
							$twitter_url = get_theme_mod('twitter_url');
							if ($twitter_url) {
								echo '<a href="' . esc_url($twitter_url) . '" target="_blank"><svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="" class="bi bi-twitter-x" viewBox="0 0 16 16"><path d="M12.6.75h2.454l-5.36 6.142L16 15.25h-4.937l-3.867-5.07-4.425 5.07H.316l5.733-6.57L0 .75h5.063l3.495 4.633L12.601.75Zm-.86 13.028h1.36L4.323 2.145H2.865l8.875 11.633Z"/></svg></a>';
							}
							$github_url = get_theme_mod('github_url');
							if ($github_url) {
								echo '<a href="' . esc_url($github_url) . '" target="_blank"><i class="bi bi-github"></i></a>';
							} ?>
						<?php endif ?>
					</div>
			</div>
		</div>
		<header id="masthead" class="site-header">
			<div class="site-branding">
				<?php if (is_front_page() && is_home()) : ?>
					<div class="site-title-grop-header">
					    <?php if($novus_logo_upload = get_theme_mod('custom_logo')){ ?>
						<div class="loghetto">
						<img class="loghetto-img" src="<?php echo esc_url(wp_get_attachment_url(get_theme_mod('custom_logo'))); ?>" />
				        </div>
                        <?php } ?>
						<h1 class="site-title"><b><?php bloginfo('name'); ?></b> </h1>
						<p class="site-description"><?php bloginfo('description'); ?></p>
						<?php if (get_theme_mod('button_show_hide', '0') == '1') { ?>
							<a href="<?php echo esc_html(get_theme_mod('button_header_url')); ?>" class="btn btn-outline-dark"><?php echo esc_html(get_theme_mod('text_button_header')); ?></a>
						<?php } ?>
					</div>
					<img class="sfondo-header" src="<?php header_image(); ?>" />
				<?php else : ?>
					<div class="site-title-grop-header-page">
					    <?php if($novus_logo_upload = get_theme_mod('custom_logo')){ ?>
						<div class="loghetto-page">
						<img class="loghetto-img-page" src="<?php echo esc_url(wp_get_attachment_url(get_theme_mod('custom_logo'))); ?>" />
				        </div>
                        <?php } ?>
						<h1 class="site-title-page"><?php bloginfo('name'); ?></h1>
						<p class="site-description"><?php bloginfo('description'); ?></p>
					</div>
					
				<?php endif; ?>
				
			</div><!-- .site-branding -->
			
			<nav class="navbar navbar-expand-xl navbar-light">
				<div class="container">
					<a class="navbar-brand" href="<?php echo esc_url(home_url('/')) ?>">
						<?php bloginfo('name'); ?></a>
					<button class="navbar-toggler" type="button" data-bs-toggle="offcanvas" data-bs-target="#offcanvasNavbar2" aria-controls="offcanvasNavbar2" aria-label="Toggle navigation">
						<span class="navbar-toggler-icon"></span>
					</button>
					<div class="offcanvas offcanvas-end text-bg-light" tabindex="-1" id="offcanvasNavbar2" aria-labelledby="offcanvasNavbar2Label">
						<div class="offcanvas-header">
							<h4 style="color:#930808;" class="offcanvas-title" id="offcanvasNavbar2Label"><?php echo esc_html(get_bloginfo('name')); ?></h4>
							<button type="button" class="btn-close" data-bs-dismiss="offcanvas" aria-label="Close"></button>
						</div>
						<div class="offcanvas-body">
							<?php
							wp_nav_menu(array(
								'theme_location' => 'themapuro-menu-top',
								'container' => false,
								'menu_class' => '',
								'fallback_cb' => '__return_false',
								'items_wrap' => '<ul id="%1$s" class="navbar-nav   flex-grow-1 %2$s">%3$s </ul>',
	                            'walker' => new themapuro_bootstrap_5_wp_nav_menu_walker()
							));
							?>
							<div id="overlay" class="overlay">
								<div class="overlay-content">
								    <label class="text-label" for="site-search"><?php esc_html_e('Search in the site:','themapuro');?></label>
									<form role="get_search_form" method="get" action="<?php home_url('/'); ?>">
										<div class="camporicerca">
									    <input id="themapuro-focus" type="text" value="<?php the_search_query(); ?>" name="s" id="s" placeholder="Search..."  autofocus />
						                </div>
									</form>
								</div>
								<button id="themapuro-close-overlay">Close</button>
							</div>
						<button class="bi bi-search" id="themapuro-open-overlay-button"></button>
						</nav>
			<div class="container">
				<?php if (is_front_page() && is_home()) : ?>
					<?php $themapuro_nonso = (esc_html(get_theme_mod('variabile_cate_semple')));
	
					$themapuro_query = new WP_Query(array(
						'category_name' => "$themapuro_nonso",
						'posts_per_page' => 3,
					));
					?>
					<?php if (get_theme_mod('display_flex_show_hide', '0') == '1') { ?>
						<div class="contenuto">
							<?php while ($themapuro_query->have_posts()) : $themapuro_query->the_post(); ?>
								<div class="children-baby">
									<div class="default"><a href="<?php the_permalink() ?>"><?php the_post_thumbnail(); ?></a></div>
									<div class="sistem-category">
										<h4><?php echo esc_html(get_theme_mod('sfondo_cat_display')); ?>
										<?php the_category(); ?>
									   </h4>
									</div>
									<div class="darkdiv">
										<h1><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
										<small class="permalink-s"> <i class="bi bi-calendar3"></i> <?php the_time(get_option('date_format')); ?> </a></small>
									</div>
								</div>
							<?php endwhile; ?>
							<?php wp_reset_postdata(); ?>
						</div>
					<?php } ?>
				<?php endif; ?>
		</header><!-- #masthead -->